@@ -7,7 +7,7 @@ import warnings
 from typing import cast
 
 from sdsstools import get_logger, get_package_version
-from sdsstools.configuration import __ENVVARS__, read_yaml_file
+from sdsstools.configuration import __ENVVARS__, get_config
 
 
 NAME = "sdss-cherno"
@@ -23,9 +23,9 @@ OBSERVATORY = os.environ.get("OBSERVATORY", None)
 if OBSERVATORY is None:
     OBSERVATORY = "APO"
     warnings.warn("Unknown observatory. Defaulting to APO!", UserWarning)
-
-cwd = pathlib.Path(__file__).parent
-config = read_yaml_file(str(cwd / f"etc/cherno_{OBSERVATORY}.yml"))
+    config = get_config("cherno")
+else:
+    config = get_config(f"cherno_{OBSERVATORY}")
 
 
 __version__ = cast(str, get_package_version(path=__file__, package_name=NAME))
