@@ -93,6 +93,7 @@ class AstrometricSolution:
     delta_rot: float = -999.0
     delta_scale: float = -999.0
     delta_focus: float = -999.0
+    fit_mode: str = "full"
     rms: float = -999.0
     fwhm_median: float = -999.0
     fwhm_fit: float = -999.0
@@ -148,7 +149,8 @@ class Acquisition:
             self.astrometry = astrometry
         else:
             pixel_scale = config["pixel_scale"]
-            backend_config = pathlib.Path(__file__).parent / "etc/astrometrynet.cfg"
+            astrometry_net_config = config["acquisition"]["astrometry_net_config"]
+            backend_config = pathlib.Path(__file__).parent / astrometry_net_config
             self.astrometry = AstrometryNet(
                 backend_config=str(backend_config),
                 width=2048,
@@ -184,6 +186,8 @@ class Acquisition:
         offset: list[float] | None = None,
         scale_rms: bool = True,
         wait_for_correction: bool = True,
+        only_radec: bool = False,
+        auto_radec_min: int = 2,
     ):
         """Performs extraction and astrometry."""
 
@@ -229,6 +233,8 @@ class Acquisition:
             list(acq_data),
             offset=offset,
             scale_rms=scale_rms,
+            only_radec=only_radec,
+            auto_radec_min=auto_radec_min,
         )
 
         if correct and ast_solution.valid_solution is True:
@@ -255,6 +261,8 @@ class Acquisition:
         offset: list[float] | None = None,
         scale_rms: bool = False,
         do_focus: bool = True,
+        only_radec: bool = False,
+        auto_radec_min: int = 2,
     ):
         """Calculate the astrometric solution."""
 
@@ -267,7 +275,9 @@ class Acquisition:
             self.command.error(acquisition_valid=False, did_correct=False)
             return ast_solution
 
-        fwhm = numpy.average([d.e_data.fwhm_median for d in solved], weights=weights)
+        fwhm = [d.e_data.fwhm_median for d in data if d.e_data.fwhm_median > 0]
+        fwhm = numpy.average(fwhm)
+
         camera_rotation = numpy.average([d.rotation for d in solved], weights=weights)
 
         ast_solution.fwhm_median = numpy.round(float(fwhm), 3)
@@ -301,12 +311,26 @@ class Acquisition:
         else:
             self.command.debug(offset=offset)
 
+        if only_radec is True:
+            self.command.warning(
+                "Only fitting RA/Dec. The rotation and scale offsets "
+                "are informational-only and not corrected."
+            )
+        elif auto_radec_min >= 0 and len(solved) <= auto_radec_min:
+            only_radec = True
+            self.command.warning(
+                f"Only {len(solved)} cameras solved. Only fitting RA/Dec. "
+                "The rotation and scale offsets are informational-only "
+                "and not corrected."
+            )
+
         guide_fit = self.fitter.fit(
             field_ra,
             field_dec,
             field_pa,
             offset=full_offset,
             scale_rms=scale_rms,
+            only_radec=only_radec,
         )
 
         exp_no = solved[0].exposure_no  # Should be the same for all.
@@ -332,6 +356,9 @@ class Acquisition:
         ast_solution.delta_scale = float(delta_scale)
         ast_solution.rms = float(rms)
 
+        if guide_fit.only_radec:
+            ast_solution.fit_mode = "radec"
+
         if do_focus:
             try:
                 fwhm_fit, x_min, a, b, c, r2 = focus_fit(
@@ -391,7 +418,12 @@ class Acquisition:
             ]
         )
 
-        if delta_scale > 0 and self.command.actor and fwhm < 2.5:
+        if (
+            delta_scale > 0
+            and self.command.actor
+            and fwhm < 2.5
+            and not guide_fit.only_radec
+        ):
             # If we measured the scale, add it to the actor state. This is later
             # used to compute the average scale over a period. We also add the time
             # because we'll want to reject measurements that are too old.
@@ -441,7 +473,7 @@ class Acquisition:
             coro = apply_axes_correction(
                 self.command,
                 self.pids,
-                delta_rot=data.delta_rot,
+                delta_rot=data.delta_rot if data.fit_mode == "full" else None,
                 full=full,
             )
 
@@ -450,7 +482,7 @@ class Acquisition:
                 self.command,
                 self.pids,
                 delta_radec=(data.delta_ra, data.delta_dec),
-                delta_rot=data.delta_rot,
+                delta_rot=data.delta_rot if data.fit_mode == "full" else None,
                 full=full,
             )
 
@@ -514,7 +546,7 @@ class Acquisition:
             self.command,
             self.pids,
             delta_radec=(data.delta_ra, data.delta_dec),
-            delta_rot=data.delta_rot,
+            delta_rot=data.delta_rot if data.fit_mode == "full" else None,
             delta_focus=data.delta_focus if do_focus else None,
             full=full,
             wait_for_correction=wait_for_correction,
@@ -532,7 +564,10 @@ class Acquisition:
 
     async def _astrometry_one(self, ext_data: ExtractionData):
 
-        regions = ext_data.regions.loc[ext_data.regions.valid == 1].copy()
+        if config["acquisition"]["astrometry_net_use_all_regions"]:
+            regions = ext_data.regions.copy()
+        else:
+            regions = ext_data.regions.loc[ext_data.regions.valid == 1].copy()
 
         if self.astrometry._options.get("dir", None) is None:
             astrometry_dir = pathlib.Path(config["acquisition"]["astrometry_dir"])
@@ -768,6 +803,7 @@ def update_proc_headers(data: AstrometricSolution, guider_state: ChernoState):
             header["FWHMFIT"] = (data.fwhm_fit, "Fitted FWHM [arcsec]")
 
             header["RMS"] = (rms, "Guide RMS [arcsec]")
+            header["FITMODE"] = (data.fit_mode, "Fit mode (full or RA/Dec)")
 
             header["E_RA"] = (enabled_ra, "RA corrections enabled?")
             header["E_DEC"] = (enabled_dec, "Dec corrections enabled?")
